==> order-center-domain-3.0.0-CLOUD-DEV-20250916.085506-182-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrderItemQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocOrderItemQryBo
 * 说明:销售订单明细
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrderItemQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  2032485603894562694L;

	@DocField(value = "订单明细id")
	private Long orderItemId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "明细类型             1 商品sku             2 物资             3 项目")
	private Integer itemType;

	@DocField(value = "明细状态")
	private String orderItemState;

	@DocField(value = "商品id")
	private String commodityId;

	@DocField(value = "商品名称")
	private String commodityName;

	@DocField(value = "商品类型ID")
	private String commodityTypeId;

	@DocField(value = "商品类型名称")
	private String commodityTypeName;

	@DocField(value = "外部单品ID")
	private String extSkuId;

	@DocField(value = "单品ID")
	private String skuId;

	@DocField(value = "单品名称")
	private String skuName;

	@DocField(value = "供应商ID")
	private String supplierId;

	@DocField(value = "供应商名称")
	private String supplierName;

	@DocField(value = "店铺ID")
	private String supplierShopId;

	@DocField(value = "店铺名称")
	private String supplierShopName;

	@DocField(value = "单品来源      1 自营单品   2 电商导入   3 协议生成    ")
	private Integer skuSource;

	@DocField(value = "采购金额")
	private BigDecimal purchasePrice;

	@DocField(value = "采购金额")
	private BigDecimal salePrice;

	@DocField(value = "采购数量")
	private BigDecimal purchaseCount;

	@DocField(value = "运费")
	private BigDecimal transFee;

	@DocField(value = "应付金额")
	private BigDecimal payFee;

	@DocField(value = "积分优惠金额")
	private BigDecimal integralDisFee;

	@DocField(value = "活动优惠金额")
	private BigDecimal actDisFee;

	@DocField(value = "其它优惠金额")
	private BigDecimal otherDisFee;

	@DocField(value = "实付金额")
	private BigDecimal usedFee;

	@DocField(value = "实付积分")
	private BigDecimal usedIntegral;

	@DocField(value = "币种")
	private String currencyType;

	@DocField(value = "税金")
	private String taxPrice;

	@DocField(value = "税率")
	private String tax;

	@DocField(value = "预计发货时间")
	private Date preSendTime;

	@DocField(value = "预计发货时间 开始")
	private Date preSendTimeStart;

	@DocField(value = "预计发货时间 结束")
	private Date preSendTimeEnd;

	@DocField(value = "预计交货时间")
	private Date preOfferTime;

	@DocField(value = "预计交货时间 开始")
	private Date preOfferTimeStart;

	@DocField(value = "预计交货时间 结束")
	private Date preOfferTimeEnd;

	@DocField(value = "计量单位")
	private String unitName;

	@DocField(value = "结算计量单位")
	private String settleUnit;

	@DocField(value = "外部电商主订单id")
	private String imOrderId;

	@DocField(value = "外部电商子订单id")
	private String imSubOrderId;

	@DocField(value = "到货周期")
	private String arrivalTime;

	@DocField(value = "加价率")
	private Double markUpRate;

	@DocField(value = "商品服务费 ")
	private String serPrice;

	@DocField(value = "计划编号")
	private String planNo;

	@DocField(value = "计划明细编号")
	private String planItemNo;

	@DocField(value = "超验百分比，下单时保存（协议、无协议）")
	private Integer inspectionExcessPercent;

	@DocField(value = "税务编码")
	private String taxId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "扩展字段")
	private String extField1;

	@DocField(value = "扩展字段")
	private String extField2;

	@DocField(value = "扩展字段")
	private String extField3;

	@DocField(value = "扩展字段")
	private String extField4;

	@DocField(value = "扩展字段")
	private String extField5;

	@DocField(value = "扩展字段")
	private String extField6;

	@DocField(value = "扩展字段")
	private String extField7;

	@DocField(value = "扩展字段")
	private String extField8;

	@DocField(value = "扩展字段")
	private String extField9;

	@DocField(value = "扩展字段")
	private String extField10;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;
	/**
	 * 租户id
	 */
	private Long sysTenantId;
	private String sysTenantName;

}

==> order-center-domain-3.2.2-CLOUD-DEV-20240710.070108-26-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrderItemQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocOrderItemQryBo
 * 说明:销售订单明细
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrderItemQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  2032485603894562694L;

	//订单明细id")
	private Long orderItemId;

	//订单id")
	private Long orderId;

	//明细类型             1 商品sku             2 物资             3 项目")
	private Integer itemType;

	//明细状态")
	private String orderItemState;

	//商品id")
	private String commodityId;

	//商品名称")
	private String commodityName;

	//商品类型ID")
	private String commodityTypeId;

	//商品类型名称")
	private String commodityTypeName;

	//外部单品ID")
	private String extSkuId;

	//单品ID")
	private String skuId;

	//单品名称")
	private String skuName;

	//供应商ID")
	private String supplierId;

	//供应商名称")
	private String supplierName;

	//店铺ID")
	private String supplierShopId;

	//店铺名称")
	private String supplierShopName;

	//单品来源      1 自营单品   2 电商导入   3 协议生成    ")
	private Integer skuSource;

	//采购金额")
	private BigDecimal purchasePrice;

	//采购金额")
	private BigDecimal salePrice;

	//采购数量")
	private BigDecimal purchaseCount;

	//运费")
	private BigDecimal transFee;

	//应付金额")
	private BigDecimal payFee;

	//积分优惠金额")
	private BigDecimal integralDisFee;

	//活动优惠金额")
	private BigDecimal actDisFee;

	//其它优惠金额")
	private BigDecimal otherDisFee;

	//实付金额")
	private BigDecimal usedFee;

	//实付积分")
	private BigDecimal usedIntegral;

	//币种")
	private String currencyType;

	//税金")
	private String taxPrice;

	//税率")
	private String tax;

	//预计发货时间")
	private Date preSendTime;

	//预计发货时间 开始")
	private Date preSendTimeStart;

	//预计发货时间 结束")
	private Date preSendTimeEnd;

	//预计交货时间")
	private Date preOfferTime;

	//预计交货时间 开始")
	private Date preOfferTimeStart;

	//预计交货时间 结束")
	private Date preOfferTimeEnd;

	//计量单位")
	private String unitName;

	//结算计量单位")
	private String settleUnit;

	//外部电商主订单id")
	private String imOrderId;

	//外部电商子订单id")
	private String imSubOrderId;

	//到货周期")
	private String arrivalTime;

	//加价率")
	private Double markUpRate;

	//商品服务费 ")
	private String serPrice;

	//计划编号")
	private String planNo;

	//计划明细编号")
	private String planItemNo;

	//超验百分比，下单时保存（协议、无协议）")
	private Integer inspectionExcessPercent;

	//税务编码")
	private String taxId;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//扩展字段")
	private String extField1;

	//扩展字段")
	private String extField2;

	//扩展字段")
	private String extField3;

	//扩展字段")
	private String extField4;

	//扩展字段")
	private String extField5;

	//扩展字段")
	private String extField6;

	//扩展字段")
	private String extField7;

	//扩展字段")
	private String extField8;

	//扩展字段")
	private String extField9;

	//扩展字段")
	private String extField10;

	//删除标志1已删除")
	private Integer delTag;

	//排序")
	private String orderBy;

}
